/*
	dialogs.c

	gmas - A file/stream viewer
	Copyright (C) 1999   Roberto Machorro (rmach@bigfoot.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "dialogs.h"

void closeDialog(GtkWidget *widget, gpointer data)
{
	gtk_widget_destroy(data);
}

void askForString(gchar *title, gchar *defstr, GtkSignalFunc callback)
{
	GtkWidget *dialog;
	GtkWidget *container;
	GtkWidget *input;
	GtkWidget *buttonArray;
	GtkWidget *okBtn;
	GtkWidget *cancelBtn;

	dialog = gtk_window_new(GTK_WINDOW_DIALOG);
	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
	gtk_window_set_title(GTK_WINDOW(dialog), title);

	container = gtk_vbox_new(FALSE, 0);
	gtk_container_border_width(GTK_CONTAINER(container), 5);
	gtk_container_add(GTK_CONTAINER(dialog), container);

	input = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(input), defstr);
	gtk_box_pack_start(GTK_BOX(container), input, TRUE, TRUE, 0);

	buttonArray = gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(container), buttonArray, TRUE, TRUE, 5);

	okBtn = gtk_button_new_with_label("Ok");
	gtk_signal_connect(GTK_OBJECT(okBtn), "clicked",
			   callback,
			   input);
	gtk_signal_connect(GTK_OBJECT(okBtn), "clicked",
			   GTK_SIGNAL_FUNC(closeDialog),
			   dialog);
	gtk_box_pack_start(GTK_BOX(buttonArray), okBtn, TRUE, TRUE, 1);

	cancelBtn = gtk_button_new_with_label("Cancel");
	gtk_signal_connect(GTK_OBJECT(cancelBtn), "clicked",
			   GTK_SIGNAL_FUNC(closeDialog),
			   dialog);
	gtk_box_pack_start(GTK_BOX(buttonArray), cancelBtn, TRUE, TRUE, 1);

	gtk_widget_grab_focus(input);

	gtk_widget_show(cancelBtn);
	gtk_widget_show(okBtn);
	gtk_widget_show(buttonArray);
	gtk_widget_show(input);
	gtk_widget_show(container);
	gtk_widget_show(dialog);
}

void showStringMessage(gchar *title, gchar *msg)
{
	GtkWidget *dialog;
	GtkWidget *container;
	GtkWidget *message;
	GtkWidget *buttonArray;
	GtkWidget *button;

	dialog = gtk_window_new(GTK_WINDOW_DIALOG);
	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
	gtk_window_set_title(GTK_WINDOW(dialog), title);

	container = gtk_vbox_new(FALSE, 0);
	gtk_container_border_width(GTK_CONTAINER(container), 5);
	gtk_container_add(GTK_CONTAINER(dialog), container);

	message = gtk_label_new(msg);
	gtk_box_pack_start(GTK_BOX(container), message, TRUE, TRUE, 0);

	buttonArray = gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(container), buttonArray, TRUE, TRUE, 5);

	button = gtk_button_new_with_label("Ok");
	gtk_signal_connect(GTK_OBJECT(button), "clicked",
			   GTK_SIGNAL_FUNC(closeDialog),
			   dialog);
	gtk_box_pack_start(GTK_BOX(buttonArray), button, TRUE, FALSE, 0);

	gtk_widget_show(button);
	gtk_widget_show(buttonArray);
	gtk_widget_show(message);
	gtk_widget_show(container);
	gtk_widget_show(dialog);
}
