/*
	fileWindow.c

	gmas - A file/stream viewer
	Copyright (C) 1999   Roberto Machorro (rmach@bigfoot.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "fileWindow.h"
#include "toolBar.h"
#include "util.h"
#include "dialogs.h"
#include "pix/gmas.xpm"

void delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
{
	closeWindowQuit(widget);
}

GtkWidget *createFileWindow(char *fileName)
{
	GtkWidget *window;
	GtkWidget *container;
	GtkWidget *toolBar;
	GtkWidget *table;
	GtkWidget *hscrollbar;
	GtkWidget *vscrollbar;
	GtkWidget *text;
	GdkPixmap *icon;
	GdkBitmap *mask;
	GtkStyle *style;

	addWindowCount();
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);

	if (fileName == NULL) {
		gtk_window_set_title(GTK_WINDOW(window), "Standard Input");
	} else {
		gtk_window_set_title(GTK_WINDOW(window), fileName);
	}

	gtk_signal_connect(GTK_OBJECT(window), "delete_event",
			   GTK_SIGNAL_FUNC(delete_event), NULL);

	container = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), container);

	table = gtk_table_new(2, 2, FALSE);
	gtk_table_set_row_spacing(GTK_TABLE (table), 0, 2);
	gtk_table_set_col_spacing(GTK_TABLE (table), 0, 2);

	text = gtk_text_new(NULL, NULL);
	gtk_text_set_editable(GTK_TEXT(text), FALSE);
	gtk_table_attach(GTK_TABLE(table), text, 0, 1, 0, 1,
			 GTK_EXPAND | GTK_SHRINK | GTK_FILL,
			 GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
	gtk_widget_set_usize(text, 500, 300);
	gtk_widget_grab_focus(text);
	gtk_widget_show(text);

	hscrollbar = gtk_hscrollbar_new(GTK_TEXT(text)->hadj);
	gtk_table_attach(GTK_TABLE(table), hscrollbar, 0, 1, 1, 2,
			 GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL, 0, 0);
	gtk_widget_show(hscrollbar);

	vscrollbar = gtk_vscrollbar_new(GTK_TEXT(text)->vadj);
	gtk_table_attach(GTK_TABLE(table), vscrollbar, 1, 2, 0, 1,
			 GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
	gtk_widget_show(vscrollbar);

	gtk_text_freeze(GTK_TEXT(text));

	toolBar = createToolBar(window, container, text);

	gtk_box_pack_start(GTK_BOX(container), toolBar, FALSE, TRUE, 0);
	gtk_box_pack_start(GTK_BOX(container), table, TRUE, TRUE, 0);

	gtk_widget_show(toolBar);
	gtk_widget_show(table);
	gtk_widget_show(container);

	style = gtk_widget_get_style(window);
	icon = gdk_pixmap_create_from_xpm_d(window->window, &mask,
					      &style->bg[GTK_STATE_NORMAL],
					      gmas_xpm);
	gdk_window_set_icon(window->window, NULL, icon, mask);

	if (!readFileToTextWidget(text, fileName)) {
		showStringMessage("Unable to read file!", fileName);
	}

	return window;
}
