/*
	toolBar.c

	gmas - A file/stream viewer
	Copyright (C) 1999   Roberto Machorro (rmach@bigfoot.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <string.h> /* strstr() */
#include "toolBar.h"
#include "util.h"
#include "dialogs.h"
#include "pix/find.xpm"
#include "pix/fsame.xpm"
#include "pix/copy.xpm"
#include "pix/close.xpm"
#include "pix/about.xpm"

GtkWidget *currentText = NULL;
gchar *findAgainString = NULL;

static void handleSearchRequest(GtkWidget *widget, gpointer data)
{
	gint currentPos;
	gint findStart;
	gint findEnd;
	guint textLength;
	gchar *findString;
	gchar *textString;
	gchar *foundString;

	if (data == NULL)
		findString = findAgainString;
	else {
		findString = gtk_entry_get_text(GTK_ENTRY(data));
		if (findAgainString != NULL)
			g_free(findAgainString);
		findAgainString = g_strdup(findString);
	}

	currentPos = gtk_editable_get_position(GTK_EDITABLE(currentText));
	textLength = gtk_text_get_length(GTK_TEXT(currentText));
	textString = gtk_editable_get_chars(GTK_EDITABLE(currentText),
					    currentPos, textLength);
	foundString = strstr(textString, findString);
	if (foundString != NULL) {
		findStart = textLength - strlen(foundString);
		findEnd = findStart + strlen(findString);
		gtk_editable_set_position(GTK_EDITABLE(currentText), findEnd);
		gtk_editable_select_region(GTK_EDITABLE(currentText), findStart, findEnd);
	} else {
		showStringMessage("Find...", "String not found!");
	}
}

static void find_string(GtkWidget *widget, gpointer data)
{
	currentText = data;
	askForString("Find...", "", GTK_SIGNAL_FUNC(handleSearchRequest));
}

static void find_same(GtkWidget *widget, gpointer data)
{
	if (findAgainString != NULL)
		handleSearchRequest(widget, NULL);
	else
		showStringMessage("Error!", "No previous find request...");
}

static void copy_text(GtkWidget *widget, gpointer data)
{
	gtk_editable_copy_clipboard(data);
}

static void close_window(GtkWidget *widget, gpointer data)
{
	closeWindowQuit((GtkWidget *)data);
}

static void about(GtkWidget *widget, gpointer data)
{
	showStringMessage("About...",
			  "Gmas 1.1 (GPL)\n(c)1999 Roberto Machorro Angoa");
}

GtkWidget *createToolBar(GtkWidget *mainWindow,
			 GtkWidget *parent,
			 GtkWidget *textWindow)
{
	GtkWidget *handleBox;
	GtkWidget *toolBar;

	currentText = NULL;
	findAgainString = NULL;

	if (!GTK_WIDGET_REALIZED(mainWindow))
		gtk_widget_realize(mainWindow);

	toolBar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,GTK_TOOLBAR_BOTH);
	gtk_toolbar_set_button_relief(GTK_TOOLBAR(toolBar), GTK_RELIEF_NORMAL);

	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), "Find...",
			      "Find string in text...", NULL,
			      createPixmapWidgetFromData(mainWindow, find_xpm),
			      (GtkSignalFunc)find_string,
			      textWindow);
	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), "Find Same",
			     "Find string in text, again", NULL,
       		             createPixmapWidgetFromData(mainWindow, fsame_xpm),
			     (GtkSignalFunc)find_same,
			     textWindow);
	gtk_toolbar_append_space(GTK_TOOLBAR(toolBar));

	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), "Copy",
			      "Copies selected text to clipboard", NULL,
			      createPixmapWidgetFromData(mainWindow, copy_xpm),
			      (GtkSignalFunc)copy_text,
			      textWindow);
	gtk_toolbar_append_space(GTK_TOOLBAR(toolBar));

	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), "Close",
			     "Close this window", NULL,
			     createPixmapWidgetFromData(mainWindow, close_xpm),
			     (GtkSignalFunc)close_window,
			     mainWindow);
	gtk_toolbar_append_space(GTK_TOOLBAR(toolBar));

	gtk_toolbar_append_item(GTK_TOOLBAR(toolBar), "About...",
			     "About Gmas...", NULL,
			     createPixmapWidgetFromData(mainWindow, about_xpm),
			     (GtkSignalFunc)about,
			     textWindow);

	handleBox = gtk_handle_box_new();
	gtk_container_add(GTK_CONTAINER(handleBox), toolBar);
	gtk_widget_show(toolBar);

	return handleBox;
}
