/*
	util.c

	gmas - A file/stream viewer
	Copyright (C) 1999   Roberto Machorro (rmach@bigfoot.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include "util.h"

gint windowCount = 0;

gint addWindowCount()
{
	return (++windowCount);
}

gint chopWindowCount()
{
	if (windowCount > 0)
		windowCount--;
	return windowCount;
}

gint getWindowCount()
{
	return windowCount;
}

void closeWindowQuit(GtkWidget *window)
{
	if (getWindowCount() > 1) {
		gtk_widget_destroy(window);
		chopWindowCount();
	} else {
		gtk_main_quit();
	}
}

GtkWidget *createPixmapWidgetFromData(GtkWidget *mainWindow, char **data)
{
	GtkWidget *widgetPixmap;
	GdkPixmap *pixmap;
	GdkBitmap *mask;
	GtkStyle *style;

	style = gtk_widget_get_style(mainWindow);
	pixmap = gdk_pixmap_create_from_xpm_d(mainWindow->window, &mask,
					      &style->bg[GTK_STATE_NORMAL],
					      (gchar **)data);
	widgetPixmap = gtk_pixmap_new(pixmap, mask);
	gtk_widget_show(widgetPixmap);

	return widgetPixmap;
}

gboolean readFileToTextWidget(GtkWidget *widget, char *fileName)
{
	FILE *fhandle;

	if (fileName == NULL) {
		fhandle = stdin;
	} else {
		fhandle = fopen(fileName, "r");
	}

	if (fhandle) {
		char *buffer;
		int nbytes_read, nbytes_alloc;

		nbytes_read = 0;
		nbytes_alloc = 1024;
		buffer = g_new(char, nbytes_alloc);
		while (1) {
			int len;
			if (nbytes_alloc < nbytes_read + 1024) {
				nbytes_alloc *= 2;
				buffer = g_realloc(buffer, nbytes_alloc);
			}
			len = fread(buffer + nbytes_read, 1, 1024, fhandle);
			nbytes_read += len;
			if (len < 1024)
				break;
		}
	  
		gtk_text_insert(GTK_TEXT(widget), NULL, NULL,
				NULL, buffer, nbytes_read);
		g_free(buffer);
		fclose (fhandle);

		return TRUE;
	}

	return FALSE;
}
